@@ -72,7 +72,7 @@
 #include "theStream.h"
 #include "ui_videoSettingsWidget.h"
 #include "videoWindow.h"
-#include "audioView.h"
+#include "audioView2.h"
 #include "loadView.h"
 
 #include <phonon/backendcapabilities.h>
@@ -84,8 +84,6 @@ namespace Dragon {
     /// @see codeine.h
     QWidget* mainWindow() { return MainWindow::s_instance; }
 
-
-
 MainWindow::MainWindow()
         : KXmlGuiWindow()
         , m_mainView( 0 )
@@ -119,7 +117,7 @@ MainWindow::MainWindow()
     m_positionSlider = videoWindow()->newPositionSlider();
 
     m_mainView->addWidget(m_loadView);
-    m_audioView = new AudioView(this);
+    m_audioView = new AudioView2(this);
     m_mainView->addWidget(m_audioView);
     m_mainView->addWidget(videoWindow());
     m_mainView->setCurrentWidget(m_loadView);
@@ -240,20 +238,6 @@ MainWindow::init()
     QApplication::restoreOverrideCursor();
     engineStateChanged(Phonon::StoppedState);//set everything as it would be in stopped state
     engineSeekableChanged(false);
-
-    if( !kapp->isSessionRestored() ) {
-        KCmdLineArgs &args = *KCmdLineArgs::parsedArgs();
-        if (args.isSet( "play-dvd" ))
-            playDisc();
-        else if (args.count() > 0 ) {
-            this->open( args.url( 0 ) );
-            args.clear();
-            adjustSize(); //will resize us to reflect the videoWindow's sizeHint()
-        }
-    }
-    else
-        //session management must be done after the videoWindow() has been initialised
-        restore( 1, false );
 }
 
 MainWindow::~MainWindow()
@@ -276,13 +260,12 @@ void MainWindow::closeEvent (QCloseEvent *event)
 
 void MainWindow::wheelEvent (QWheelEvent *event)
  {
-    if (event->delta() > 0) {
-	engine()->tenPercentBack();
-      } else {
-	engine()->tenPercentForward();
-    }
+    if (event->delta() > 0)
+        engine()->increaseVolume();
+    else
+        engine()->decreaseVolume();
     event->accept();
- }
+}
 
 void
 MainWindow::setupActions()
@@ -311,6 +294,16 @@ MainWindow::setupActions()
                                                       menuBar(),
                                                       SLOT(setVisible(bool))));
 
+    KAction *action = new KAction(i18nc("@action", "Increase Volume"), ac);
+    action->setObjectName(QLatin1String("volume_inc"));
+    connect(action, SIGNAL(triggered()), engine(), SLOT(increaseVolume()));
+    addToAc(action);
+
+    action = new KAction(i18nc("@action", "Decrease Volume"), ac);
+    action->setObjectName(QLatin1String("volume_dec"));
+    connect(action, SIGNAL(triggered()), engine(), SLOT(decreaseVolume()));
+    addToAc(action);
+
     KAction* playerStop = new KAction( KIcon(QLatin1String( "media-playback-stop" )), i18n("Stop"), ac );
     playerStop->setObjectName( QLatin1String( "stop" ) );
     playerStop->setShortcut( Qt::Key_S );
@@ -346,6 +339,16 @@ MainWindow::setupActions()
     connect( videoSettings, SIGNAL(toggled(bool)), this, SLOT(toggleVideoSettings(bool)) );
     addToAc( videoSettings )
 
+    KAction* uniqueToggle =
+            new KAction( i18nc("@action:inmenu Whether only one instance of dragon can be started"
+                               " and will be reused when the user tries to play another file.",
+                               "One Instance Only"), ac );
+    uniqueToggle->setObjectName( QLatin1String( "unique" ) );
+    uniqueToggle->setCheckable( true );
+    uniqueToggle->setChecked( !KGlobal::config()->group("General").readEntry("MultipleInstances", QVariant(false)).toBool() );
+    connect( uniqueToggle, SIGNAL(toggled(bool)), this, SLOT(toggleUnique(bool)) );
+    addToAc( uniqueToggle )
+
     KAction* prev_chapter = new KAction( KIcon(QLatin1String( "media-skip-backward" )), i18n("Previous Chapter"), ac );
     prev_chapter->setObjectName( QLatin1String( "prev_chapter" ) );
     prev_chapter->setShortcut( Qt::Key_Comma );
@@ -386,6 +389,13 @@ MainWindow::setupActions()
     #undef addToAc
 }
 
+void
+MainWindow::toggleUnique( bool unique )
+{
+    KGlobal::config()->group("General").writeEntry("MultipleInstances", !unique);
+    KGlobal::config()->sync();
+}
+
 void
 MainWindow::toggleVideoSettings( bool show )
 {
@@ -634,7 +644,7 @@ MainWindow::openFileDialog()
     }
     else
     {
-        load( url );
+        open( url );
     }
 }
 
@@ -685,6 +695,19 @@ MainWindow::openRecentFile( const KUrl& url )
     this->open( url );
 }
 
+void
+MainWindow::parseArgs()
+{
+    KCmdLineArgs &args = *KCmdLineArgs::parsedArgs();
+    if (args.isSet( "play-dvd" ))
+        playDisc();
+    else if (args.count() > 0 ) {
+        open( args.url( 0 ) );
+        args.clear();
+        adjustSize(); //will resize us to reflect the videoWindow's sizeHint()
+    }
+}
+
 void
 MainWindow::setFullScreen( bool isFullScreen )
 {
